wcmd autoexec.bat?

davep davep at cyw.uklinux.net
Tue Feb 18 10:54:23 CST 2003


On Monday 17 Feb 2003 23:59, J. Grant wrote:
> Hi,
>
> Bodo Wenzel wrote:
> >> I think this is a key feature, I would like to use this to set some
> >> environment variables, currently I have to run a batch file manually
> >> each time I start wcmd.  Could this be considered for implementation
> >> please?
> >
> > The real-mode emulator 'dosemu' has an option to use another extension
> > for 'autoexec.bat' and 'config.sys'. How about 'autoexec.wine' and
> > 'config.wine', respectively? Just my EUR 0.02 ;-)
>
> This looks like an interesting idea you have Bodo. "autoexec.wine" would
> be useful.

Something like this?

Index: programs/wcmd/wcmdmain.c
===================================================================
RCS file: /home/wine/wine/programs/wcmd/wcmdmain.c,v
retrieving revision 1.22
diff -u -r1.22 wcmdmain.c
--- programs/wcmd/wcmdmain.c    11 Feb 2003 22:01:11 -0000      1.22
+++ programs/wcmd/wcmdmain.c    18 Feb 2003 16:51:42 -0000
@@ -102,16 +102,14 @@
   }

 /*
  *     If there is an AUTOEXEC.BAT file, try to execute it.
  */

-  GetFullPathName ("\\autoexec.bat", sizeof(string), string, NULL);
+  GetFullPathName ("\\autoexec.wine", sizeof(string), string, NULL);
   h = CreateFile (string, GENERIC_READ, FILE_SHARE_READ, NULL, OPEN_EXISTING, 
FILE_ATTRIBUTE_NORMAL, NULL);
   if (h != INVALID_HANDLE_VALUE) {
     CloseHandle (h);
-#if 0
     WCMD_batch (string, " ");
-#endif
   }

 /*
@@ -102,16 +102,14 @@

 /*
- *     If there is an AUTOEXEC.BAT file, try to execute it.
+ *     If there is an AUTOEXEC.WINE file, try to execute it.
  */



-- 
Dave Pickles



More information about the wine-devel mailing list